@@ -1,7 +1,13 @@
 // SPDX-License-Identifier: MIT
-mod request;
 pub use lamedh_runtime::Error as LambdaError;
 
+#[cfg(test)]
+#[cfg(any(feature = "actix4", feature = "rocket05", feature = "warp03"))]
+mod test_consts;
+
+#[cfg(any(feature = "actix4", feature = "rocket05", feature = "warp03"))]
+mod request;
+
 #[cfg(feature = "actix4")]
 mod actix4;
 #[cfg(feature = "actix4")]
